@@ -585,7 +585,7 @@ NMVariantMapMap OpenVpnUiPlugin::importConnectionSettings(const QString &fileNam
                 list << ipRoute;
             }
             QList<QList<uint> > dbusRoutes;
-            Q_FOREACH (const NetworkManager::IpRoute &route, list) {
+            for (const NetworkManager::IpRoute &route : list) {
                 QList<uint> dbusRoute;
                 dbusRoute << htonl(route.ip().toIPv4Address())
                         << route.prefixLength()
@@ -857,7 +857,7 @@ bool OpenVpnUiPlugin::exportConnectionSettings(const NetworkManager::ConnectionS
     // Export X-NM-Routes
     if (!ipv4Setting->routes().isEmpty()) {
         QString routes;
-        Q_FOREACH (const NetworkManager::IpRoute &route, ipv4Setting->routes()) {
+        for (const NetworkManager::IpRoute &route : ipv4Setting->routes()) {
             routes += route.ip().toString() % QLatin1Char('/') % QString::number(route.prefixLength()) % QLatin1Char(' ');
         }
         if (!routes.isEmpty()) {
